@@ -1,7 +1,8 @@
 # from examples.langchain_example.basic import basic, load_and_split, rag
 
 
-# from examples.openai.chat_completion import chat_completion
+from examples.openai.chat_completion import chat_completion
+
 # from examples.openai import images_generate
 # from examples.openai.function_calling import function_calling
 # from examples.anthropic_example.completion import messages_create
@@ -9,12 +10,12 @@
 # from examples.pinecone_example.basic import basic
 # from examples.chroma_example.basic import basic
 # from examples.llamaindex_example.basic import basic
-from examples.langchain_example.basic import basic
+# from examples.langchain_example.basic import basic
 
 # load_and_split()
 # rag()
-basic()
-# chat_completion()
+# basic()
+chat_completion()
 # function_calling()
 # images_generate()
 # embeddings_create()
